==> pytsite-3.0-py3-none-any.whl: pytsite/assetman/res/assets/assetman.js <==
define(['jquery', 'assetman-build-timestamps'], function ($, tStamps) {
    function assetUrl(url) {
        if (url.indexOf('/') === 0 || url.indexOf('http') === 0)
            return url;

        var pkgName = $('meta[name="pytsite-theme"]').attr('content');
        var assetPath = url;
        var urlParts = url.split('@');

        if (urlParts.length === 2) {
            pkgName = urlParts[0];
            assetPath = urlParts[1];
        }

        return location.origin + '/assets/' + pkgName + '/' + assetPath + '?v=' + tStamps[pkgName];
    }

    function loadAssets(loc) {
        var defer = $.Deferred();

        setTimeout(function () {
            var loadedLocationsCount = 0;

            if (loc instanceof String)
                loc = [loc];

            if (loc.length) {
                for (var i = 0; i < loc.length; i++) {
                    var assetSrc, assetType;

                    if (typeof loc[i] === 'string') {
                        assetSrc = loc[i];
                        if (loc[i].indexOf('.js') > 0)
                            assetType = 'js';
                        else if (loc[i].indexOf('.css') > 0)
                            assetType = 'css';
                    }
                    else if (loc[i] instanceof Array) {
                        assetSrc = loc[i][0];
                        if (loc[i][1] === 'js')
                            assetType = 'js';
                        else if (loc[i][1] === 'css')
                            assetType = 'css';
                    }

                    switch (assetType) {
                        case 'js':
                            loadJS(assetSrc, i)
                                .done(function () {
                                    if (++loadedLocationsCount === loc.length)
                                        defer.resolve();
                                });
                            break;

                        case 'css':
                            loadCSS(assetSrc, i)
                                .done(function () {
                                    if (++loadedLocationsCount === loc.length)
                                        defer.resolve();
                                });
                            break;

                        default:
                            defer.reject();
                            throw "Cannot determine type of the asset '" + assetSrc + "'.";
                    }
                }
            }
            else {
                defer.resolve();
            }
        }, 0);

        return defer;
    }

    function loadJS(loc, callback, async) {
        function doLoad() {
            loc = assetUrl(loc);
            if (!$('script[src^="' + loc.replace(/\?v=[0-9a-f]+/, '') + '"]').length) {
                $('body').append($('<script type="text/javascript" src="' + loc + '"></script>'));
            }

            if (callback)
                callback(loc);
        }

        if (async === undefined)
            async = true;

        if (async) {
            var deferred = $.Deferred();

            setTimeout(function () {
                doLoad();
                deferred.resolve();
            }, 0);

            return deferred;
        }
        else
            doLoad();
    }

    function loadCSS(loc, callback, async) {
        function doLoad() {
            loc = assetUrl(loc);
            if (!$('link[href^="' + loc.replace(/\?v=[0-9a-f]+/, '') + '"]').length) {
                $('head').append($('<link rel="stylesheet" href="' + loc + '">'));
            }

            if (callback)
                callback(loc);
        }


        if (async === undefined)
            async = true;

        if (async) {
            var deferred = $.Deferred();

            setTimeout(function () {
                doLoad();
                deferred.resolve();
            }, 0);

            return deferred;
        }
        else
            doLoad();
    }

    function parseLocation(skipEmpty) {
        function split(s) {
            var r = {};

            s = s.split('&');
            for (var i = 0; i < s.length; ++i) {
                var part = s[i].split('=');
                if (part.length === 1 && part[0].length) {
                    r[decodeURIComponent(part[0])] = null;
                }
                else if (part.length === 2) {
                    var k = decodeURIComponent(part[0].replace('+', '%20'));
                    var v = decodeURIComponent(part[1].replace('+', '%20'));

                    if (k.indexOf('[]') > 0) {
                        k = k.replace('[]', '');

                        if (k in r && !(r[k] instanceof Array))
                            r[k] = [r[k]];
                        else
                            r[k] = [];

                        r[k].push(v);
                    }
                    else {
                        r[k] = v;
                    }
                }
            }

            for (var l in r) {
                if (r[l] instanceof Array && r[l].length === 1)
                    r[l] = r[l][0];

                if (skipEmpty === true && !r[l])
                    delete r[l];
            }

            return r;
        }

        return {
            href: window.location.href,
            origin: window.location.origin,
            protocol: window.location.protocol,
            host: window.location.host,
            port: window.location.port,
            pathname: window.location.pathname,
            query: split(window.location.search.replace(/^\?/, '')),
            hash: split(window.location.hash.replace(/^#/, ''))
        };
    }

    function encodeQuery(data) {
        var r = [];
        for (var k in data) {
            if (data.hasOwnProperty(k)) {
                if (data.k instanceof Array) {
                    for (var l = 0; l < data.k.length; l++) {
                        r.push(encodeURIComponent(k) + "[]=" + encodeURIComponent(data[k][l]));
                    }
                }
                else {
                    r.push(encodeURIComponent(k) + "=" + encodeURIComponent(data[k]));
                }
            }
        }

        return r.join("&");
    }

    return {
        assetUrl: assetUrl,
        loadAssets: loadAssets,
        loadJS: loadJS,
        loadCSS: loadCSS,
        parseLocation: parseLocation,
        encodeQuery: encodeQuery
    }
});

==> pytsite-4.0.4-py3-none-any.whl: pytsite/assetman/res/assets/assetman.js <==
define(['jquery', 'assetman-build-timestamps'], function ($, tStamps) {
    function assetUrl(url) {
        if (url.indexOf('/') === 0 || url.indexOf('http') === 0)
            return url;

        var pkgName = $('meta[name="pytsite-theme"]').attr('content');
        var assetPath = url;
        var urlParts = url.split('@');

        if (urlParts.length === 2) {
            pkgName = urlParts[0];
            assetPath = urlParts[1];
        }

        return location.origin + '/assets/' + pkgName + '/' + assetPath + '?v=' + tStamps[pkgName];
    }

    function loadResource(resType, resLoc, callbackFunc, async) {
        resLoc = assetUrl(resLoc).replace(/\?v=[0-9a-f]+/, '');

        // Async is default for CSS but not for JS
        if (async === undefined)
            async = resType !== 'JS';

        // Call self in async manner
        if (async === true) {
            var deferred = $.Deferred();

            setTimeout(function () {
                // It is important to pass 'false' as last argument!
                loadResource(resType, resLoc, callbackFunc, false);
                deferred.resolve();
            }, 0);

            return deferred;
        }

        switch (resType) {
            case 'css':
                if (!$('link[href^="' + resLoc + '"]').length)
                    $('head').append($('<link rel="stylesheet" href="' + resLoc + '">'));
                break;

            case 'js':
                if (!$('script[src^="' + resLoc + '"]').length)
                    $('body').append($('<script type="text/javascript" src="' + resLoc + '"></script>'));
                break;

            default:
                throw 'Unexpected resource type: ' + resType;
        }

        if (callbackFunc)
            callbackFunc(resLoc);
    }

    function loadJS(location, callback, async) {
        return loadResource('js', location, callback, async)
    }

    function loadCSS(location, callback, async) {
        return loadResource('css', location, callback, async)
    }

    function parseLocation(skipEmpty) {
        function split(s) {
            var r = {};

            s = s.split('&');
            for (var i = 0; i < s.length; ++i) {
                var part = s[i].split('=');
                if (part.length === 1 && part[0].length) {
                    r[decodeURIComponent(part[0])] = null;
                }
                else if (part.length === 2) {
                    var k = decodeURIComponent(part[0].replace('+', '%20'));
                    var v = decodeURIComponent(part[1].replace('+', '%20'));

                    if (k.indexOf('[]') > 0) {
                        k = k.replace('[]', '');

                        if (k in r && !(r[k] instanceof Array))
                            r[k] = [r[k]];
                        else
                            r[k] = [];

                        r[k].push(v);
                    }
                    else {
                        r[k] = v;
                    }
                }
            }

            for (var l in r) {
                if (r[l] instanceof Array && r[l].length === 1)
                    r[l] = r[l][0];

                if (skipEmpty === true && !r[l])
                    delete r[l];
            }

            return r;
        }

        return {
            href: window.location.href,
            origin: window.location.origin,
            protocol: window.location.protocol,
            host: window.location.host,
            port: window.location.port,
            pathname: window.location.pathname,
            query: split(window.location.search.replace(/^\?/, '')),
            hash: split(window.location.hash.replace(/^#/, ''))
        };
    }

    function encodeQuery(data) {
        var r = [];
        for (var k in data) {
            if (data.hasOwnProperty(k)) {
                if (data.k instanceof Array) {
                    for (var l = 0; l < data.k.length; l++) {
                        r.push(encodeURIComponent(k) + "[]=" + encodeURIComponent(data[k][l]));
                    }
                }
                else {
                    r.push(encodeURIComponent(k) + "=" + encodeURIComponent(data[k]));
                }
            }
        }

        return r.join("&");
    }

    return {
        assetUrl: assetUrl,
        loadJS: loadJS,
        loadCSS: loadCSS,
        parseLocation: parseLocation,
        encodeQuery: encodeQuery
    }
});
